@@ -263,7 +263,23 @@ window.addEventListener("message", function (message) {
 		sendComplexValue: function(methodName, param, indexCount, index0, index1, index2) {
 			return this._postMessage("SetComplexValue",{methodName: methodName, param:param, indexCount:indexCount, index0:index0, index1:index1, index2:index2}, true);
 		},
-
+		/**
+		 * Notifies Webvisu that the size of the iframe should be changed.
+		 * This can be used, for example, to implement a drop-down combo box.
+		 * @param {Number} width The new width of the iframe
+		 * @param {Number} width The new height of the iframe
+		 */
+		sendResizeRequest: function(width, height){
+			this._postMessage("SetResizeValues",{width, height}, false);
+		},
+		/**
+		 * Notifies Webvisu that the Foreground-State of the html5-element should be changed.
+		 * This can be used, for example, to implement a drop-down combo box that can overlap other elements.
+		 * @param {Number} forgroundState The new Foreground-State of the element
+		 */
+		sendChangeForegroundStateRequest: function(foregroundState){
+			this._postMessage("SetForegroundState",{foregroundState}, false);
+		},
 		/**
 		 * Internal Helper function to send messages from the element's iFrame to the webvisu.
 		 */
